[![CircleCI](https://dl.circleci.com/status-badge/img/gh/tberlok/paicos/tree/main.svg?style=svg&circle-token=dbdb37aa907d919a167a8ef5ccf197c0d358c300)](https://dl.circleci.com/status-badge/redirect/gh/tberlok/paicos/tree/main)
[![pylint](https://github.com/tberlok/paicos/actions/workflows/pylint.yml/badge.svg)](
https://github.com/tberlok/paicos/actions/workflows/pylint.yml)
[![flake8](https://github.com/tberlok/paicos/actions/workflows/flake8.yml/badge.svg)](
https://github.com/tberlok/paicos/actions/workflows/flake8.yml)
[![Documentation Status](https://readthedocs.org/projects/paicos/badge/?version=latest)](https://paicos.readthedocs.io/en/latest/?badge=latest)


# Paicos

A somewhat bare-bones Python package for making projections and slices of
Arepo simulations. Please note that while Paicos has its visibility set to
public, it is still in beta mode and under active development.

<img src="images/Z24_snap130_wide_projection_notnested.jpg" width="auto">


# Documentation

Installation instructions and tips on how to get started can be found
on [readthedocs](https://paicos.readthedocs.io/en/latest/?badge=latest).




